@@ -25,12 +25,18 @@
 #include <string.h>
 #include <unistd.h>
 #include <getopt.h>
+#include <pthread.h>
 #include "version.h"
 
 /**
  * progress.h - only for progress bar
  */
 #include "progress.h"
+void *thread_update_pui(void *arg);
+progress_bar    prog;           /// progress_bar structure defined in progress.h
+unsigned long long copied;
+unsigned long long block_id;
+int done;
 
 /**
  * partclone.h - include some structures like image_head, opt_cmd, ....
@@ -41,7 +47,6 @@
 
 /// global variable
 cmd_opt		opt;			/// cmd_opt structure defined in partclone.h
-p_dialog_mesg	m_dialog;			/// dialog format string
 char *EXECNAME="partclone.chkimg";
 
 static void usage_chkimg(void)
@@ -56,7 +61,6 @@ static void usage_chkimg(void)
 #ifdef HAVE_LIBNCURSESW
             "    -N,  --ncurses          Using Ncurses User Interface\n"
 #endif
-            "    -X,  --dialog           output message as Dialog Format\n"
             "    -F,  --force            force progress\n"
 	    "         --ignore_crc       Ignore crc check error\n"
             "    -f,  --UI-fresh         fresh times of progress\n"
@@ -73,7 +77,6 @@ static void parse_option_chkimg(int argc, char** argv, cmd_opt* option){
         { "debug",		optional_argument,  NULL,   'd' },
         { "UI-fresh",	required_argument,  NULL,   'u' },
         { "check",		no_argument,	    NULL,   'C' },
-        { "dialog",		no_argument,	    NULL,   'X' },
         { "logfile",	required_argument,  NULL,   'L' },
         { "force",		no_argument,	    NULL,   'F' },
 	{ "ignore_crc",     no_argument,    NULL,   'i' },
@@ -120,12 +123,6 @@ static void parse_option_chkimg(int argc, char** argv, cmd_opt* option){
 	    case 'i':
 		option->ignore_crc = 1;
 		break;
-            case 'X':
-                /// output message as dialog format, reference
-                /// dialog --guage is text height width percent
-                ///    A guage box displays a meter along the bottom of the box. The meter indicates the percentage. New percentages are read from standard input, one integer per line. The meter is updated to reflect each new percentage. If stdin is XXX, then the first line following is taken as an integer percentage, then subsequent lines up to another XXX are used for a new prompt. The guage exits when EOF is reached on stdin. 
-                option->dialog = 1;
-                break;
 #ifdef HAVE_LIBNCURSESW
             case 'N':
                 option->ncurses = 1;
@@ -161,7 +158,7 @@ int main(int argc, char **argv){
     int			r_size;		/// read and write size
     char*		buffer;		/// buffer data
     char*		buffer2;		/// buffer data
-    unsigned long long	block_id, copied = 0;	/// block_id is every block in partition
+    //unsigned long long	block_id, copied = 0;	/// block_id is every block in partition
     /// copied is copied block count
     off_t		offset = 0, sf = 0;	/// seek postition, lseek result
     int			start, stop;		/// start, range, stop number for progress bar
@@ -175,7 +172,7 @@ int main(int argc, char **argv){
     unsigned long	crc_ck2 = 0xffffffffL;	/// CRC32 check code for checking
     int			c_size;			/// CRC32 code size
     char*		crc_buffer;		/// buffer data for malloc crc code
-    int			done = 0;
+    //int			done = 0;
     int			s_count = 0;
     int			rescue_num = 0;
     int			tui = 0;		/// text user interface
@@ -183,7 +180,11 @@ int main(int argc, char **argv){
     int			raw = 0;
     char		image_hdr_magic[512];
 
-    progress_bar	prog;			/// progress_bar structure defined in progress.h
+    int pres;
+    pthread_t prog_thread;
+    void *p_result;
+
+    //progress_bar	prog;			/// progress_bar structure defined in progress.h
     image_head		image_hdr;		/// image_head structure defined in partclone.h
 
     /**
@@ -205,9 +206,6 @@ int main(int argc, char **argv){
     if (opt.ncurses){
         pui = NCURSES;
         log_mesg(1, 0, 0, debug, "Using Ncurses User Interface mode.\n");
-    } else if (opt.dialog){
-        pui = DIALOG;
-        log_mesg(1, 0, 0, debug, "Using Dialog User Interface mode.\n");
     } else
         pui = TEXT;
 
@@ -215,8 +213,6 @@ int main(int argc, char **argv){
     if ((opt.ncurses) && (tui == 0)){
         opt.ncurses = 0;
         log_mesg(1, 0, 0, debug, "Open Ncurses User Interface Error.\n");
-    } else if ((opt.dialog) && (tui == 1)){
-        m_dialog.percent = 1;
     }
 
     /// print partclone info
@@ -293,9 +289,14 @@ int main(int argc, char **argv){
     stop = image_hdr.usedblocks;	/// get the end of progress number, only used block
     log_mesg(1, 0, 0, debug, "Initial Progress bar\n");
     /// Initial progress bar
-    progress_init(&prog, start, stop, image_hdr.block_size);
+    progress_init(&prog, start, stop, image_hdr.totalblock, IO, image_hdr.block_size);
     copied = 1;				/// initial number is 1
 
+    /**
+     * thread to print progress
+     */
+    pres = pthread_create(&prog_thread, NULL, thread_update_pui, NULL);
+
     /**
      * start read and write data between device and image file
      */
@@ -378,10 +379,10 @@ int main(int argc, char **argv){
             log_mesg(1, 0, 0, debug, "end\n");
         }
 
-	update_pui(&prog, copied, done);
+	//update_pui(&prog, copied, block_id, done);
     } // end of for
     done = 1;
-    update_pui(&prog, copied, done);
+    update_pui(&prog, copied, block_id, done);
     print_finish_info(opt);
 
     close (dfr);    /// close source
@@ -392,3 +393,13 @@ int main(int argc, char **argv){
         close_log();
     return 0;	    /// finish
 }
+
+void *thread_update_pui(void *arg){
+
+    while (done == 0) {
+	if(!opt.quiet)
+	    update_pui(&prog, copied, block_id, done);
+    }
+    pthread_exit("exit");
+}
+
